from .shell import Shell

Shell()
